@@ -11,7 +11,7 @@ import re
 file_list = sys.argv[1:]
 
 # Exit if no files given
-if len(file_list) is 0:
+if not file_list:
     print("No files given!")
     sys.exit(0)
 
