@@ -131,9 +131,6 @@ def amz_repo_init(verbose=False):
     l = Loading("Initializing AMZ Repo")
     l.end(-2)
 
-    l.chain("Preliminary Checks - are you inside the repo root? ", "\t")
-    l.end(-3)
-
     # Check if `amz init gen` has been executed
     AMZ_INIT_EXECUTED = os.path.exists(f"{HOME_DIR}/.amz/config/amz_source.sh")
     if not AMZ_INIT_EXECUTED:
@@ -141,47 +138,62 @@ def amz_repo_init(verbose=False):
         l.end(1)
         return
 
-    # Ask if user is in AMZ_ROOT
-    while True:
-        IN_AMZ_ROOT = input("\t\t (y/n): ").lower()
-        if IN_AMZ_ROOT == 'n':
-            print("Please run this command from the repo root")
+    # Check if actually inside AMZ Repo and set root dir
+    amz_root_dir = os.getcwd()
+    if not os.path.exists('amz.yaml'):
+        # Check root of git repo.
+        try:
+            p = sp.run('git rev-parse --show-toplevel', shell=True, stdout=sp.PIPE, stderr=sp.PIPE)
+            # Check if your current repo is recognized as amz repos
+            if p.returncode == 0 and os.path.exists(f"{p.stdout.decode()[:-1]}/amz.yaml"):
+                amz_root_dir = p.stdout.decode()[:-1]
+            else:
+                print("You are not inside amz repo! Run the command from inside repo")
+                l.end(1)
+                return
+        except:
+            print("Error finding amz.yaml! Run the command from repo root")
             l.end(1)
             return
-        if IN_AMZ_ROOT not in ['y', 'n']:
-            print("Didn't quite catch you there!")
-        else:
-            break
-
-    # Check if actually inside AMZ Repo
-    if not os.path.exists('amz.yaml'):
-        print("You are lying! Not in amz repo root")
-        l.end(1)
-        return
-
-    # Fetch some data and write into amz-config YAML file
-    l.chain("Configuring the repo", "\t", 0)
 
     # Set cur dir as AMZ Root and set git repo root
-    amz_root_dir = os.getcwd()
-    auto_repo = False
+    IS_AUTO_REPO = False
     try:
         git_config = RawConfigParser()
         git_config.read(f'{amz_root_dir}/.git/config')
         amz_git_remote = git_config.get('remote "origin"', 'url')
+        # Check if it's autonomous repository
         if 'autonomous' in amz_git_remote and len(amz_git_remote.split('/')[1]) == 19:
-            auto_repo = True
+            IS_AUTO_REPO = True
     except:
         print("Is it a git repo??? and has a valid remote?")
         l.end(1)
         return
 
-    if auto_repo:
+    # Ask if user wants to set this as default AMZ autonomous repo
+    if IS_AUTO_REPO:
+        l.chain("Do you wish to set this as the default AMZ Autonomous Repo? ", "\t")
+        l.end(-3)
+
+        while True:
+            SET_DEFAULT_REPO = input("\t\t (y/n): ").lower()
+            if SET_DEFAULT_REPO not in ['y', 'n']:
+                print("Didn't quite catch you there!")
+            else:
+                break
+
+    # Fetch some data and write into amz-config YAML file
+    l.chain("Configuring the repo", "\t", 0)
+
+    if IS_AUTO_REPO:
         try:
             amz_user_config = yaml.load(open(f'{AMZ_CONFIG_DIR}/amz-config.yaml'), Loader=yaml.FullLoader)
-            amz_user_config['amz_repo_meta']['amz_root'] = amz_root_dir
-            amz_user_config['amz_repo_meta']['amz_repo_git_src'] = amz_git_remote
-            amz_user_config['amz_repo_meta']['amz_repo_config'] = f'{amz_root_dir}/amz.yaml'
+            # Setting Repo Config
+            if SET_DEFAULT_REPO:
+                amz_user_config['amz_repo_meta']['amz_root'] = amz_root_dir
+                amz_user_config['amz_repo_meta']['amz_repo_git_src'] = amz_git_remote
+                amz_user_config['amz_repo_meta']['amz_repo_config'] = f'{amz_root_dir}/amz.yaml'
+            # Append Repo to list
             if amz_user_config['amz_tool_meta']['repos'][0] == '':
                 amz_user_config['amz_tool_meta']['repos'][0] = amz_root_dir
             else:
@@ -195,10 +207,11 @@ def amz_repo_init(verbose=False):
             return
 
         # Update `amz_source.sh` with AMZ_ROOT
-        meta.update_line_in_file('export AMZ_ROOT=', f"export AMZ_ROOT={amz_root_dir}",
-                                 f"{AMZ_CONFIG_DIR}/amz_source.sh")
+        if SET_DEFAULT_REPO:
+            meta.update_line_in_file('export AMZ_ROOT=', f"export AMZ_ROOT={amz_root_dir}",
+                                     f"{AMZ_CONFIG_DIR}/amz_source.sh")
 
-    if not auto_repo:
+    if not IS_AUTO_REPO:
         try:
             amz_user_config = yaml.load(open(f'{AMZ_CONFIG_DIR}/amz-config.yaml'), Loader=yaml.FullLoader)
             if amz_user_config['amz_tool_meta']['repos'][0] == '':
@@ -222,9 +235,9 @@ def amz_repo_init(verbose=False):
         copy_tree(f'{AMZ_DATA_DIR}/githooks/config/', amz_root_dir)
         # Selectively append into .gitignore
         config_files = [file + '\n' for file in os.listdir(f'{AMZ_DATA_DIR}/githooks/config/')]
-        gi_files = open('.gitignore').readlines()
+        gi_files = open(f'{amz_root_dir}/.gitignore').readlines()
         if not set(config_files).issubset(set(gi_files)):
-            with open('.gitignore', 'a') as gi:
+            with open(f'{amz_root_dir}/.gitignore', 'a') as gi:
                 add_files = [f for f in config_files if f not in gi_files]
                 gi.writelines(['\n# Linter and Misc Configs\n'] + add_files + ['\n'])
         # Install pre-commit hook in hooks dir
